@@ -41,15 +41,26 @@ class DingDing_Push:
         self.samePubApp_link = 'https://www.qimai.cn/app/samePubApp/appid/%s/country/cn' %(self.other_var[0])
         self.app_rank_link = 'https://www.qimai.cn/app/rank/appid/%s/country/cn' %(self.other_var[0])
         self.app_keyword_link = 'https://www.qimai.cn/app/keyword/appid/%s/country/cn' %(self.other_var[0])
-        self.app_name = self.other_var[1]
-        self.samePubApp_name = self.other_var[2]
-        self.offline_time = self.other_var[3]
-        self.offline_yesterday_rank = self.other_var[4]
+        # self.app_name = self.other_var[1]
+        # self.samePubApp_name = self.other_var[2]
+        # self.offline_time = self.other_var[3]
+        # self.offline_yesterday_rank = self.other_var[4]
         payload = {
             "msgtype": "markdown",
             "markdown": {
                 "title": "【%s】%s" %(self.now_time[:10], self.push_title),
-                "text": "**推送事件**：%s\n\n**抓取时间**：%s\n\n**App名称**：[%s](%s)\n\n**开发商名称**：[%s](%s)\n\n**下架/清榜时间**：%s\n\n**下架/清榜前一日总榜**：%s" %(self.push_title, self.now_time, self.app_name, self.app_rank_link, self.samePubApp_name, self.samePubApp_link, self.offline_time, self.offline_yesterday_rank)
+                "text": "**推送事件**：%s\n\n**抓取时间**：%s\n\n**App名称**：[%s](%s)\n\n**开发商名称**：[%s](%s)\n\n**下架/清榜时间**：%s\n\n**下架/清榜前一日总榜**：%s" %(self.push_title, self.now_time, self.other_var[1], self.app_rank_link, self.other_var[2], self.samePubApp_link, self.other_var[3], self.other_var[4])
+            }
+        }
+        payload = json.dumps(payload)
+        res = requests.post(self.push_url, data=payload, headers=self.headers)
+
+    def app_args_push(self):
+        payload = {
+            "msgtype": "markdown",
+            "markdown": {
+                "title": "%s" %(self.push_title),
+                "text": "%s" %(self.other_var[0])
             }
         }
         payload = json.dumps(payload)
@@ -147,8 +158,8 @@ class qimai_outside_tool:
 
 # 计算七麦内的备用工具；
 class qimai_intside_tool:
-    def rank_type_name(self, price):
-        if price == '0.00':
+    def rank_ios10_type(self, price):
+        if price == '0.00' or price == '免费':
             return '总榜(免费)'
         else:
             return '总榜(付费)'
